# cvpa

[![PyPI](https://img.shields.io/pypi/v/cvpa?style=flat-square)](https://pypi.org/project/cvpa/)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/cvpa?style=flat-square)
[![GitHub](https://img.shields.io/github/license/cvprun/cvpa?style=flat-square)](https://github.com/cvprun/cvpa/)

**Computer Vision Player Agent**

## License

See the [LICENSE](./LICENSE) file for details. In summary,
**osom-api** is licensed under the **MIT license**.
